==> blackboardsync-0.9.11a1.tar.gz: blackboardsync-0.9.11a1/CONTRIBUTING.md <==
# Contributing to BlackboardSync

We love your input! We want to make contributing to this
project as easy and transparent as possible, whether it is:
- Reporting a issue
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer


## Our Development Process

All changes happen through pull requests,
Pull requests are the best way to propose changes.
We actively welcome your pull requests and invite you to
submit pull requests directly
[here](https://github.com/jacobszpz/BlackboardSync/pulls)
and, after review, these can be merged into the project.


## Pull Requests

1. Fork the repository and create your branch from `master`.
2. If you've added code that should be tested, add some tests.
3. Ensure to describe your pull request.


## Local Development

Follow [these instructions](#todo) to set up your own development environment.

You should use the `-d` flag of `pipenv install` to also
install development dependencies.


## Issues

We use GitHub issues to track bugs.
Please ensure your description is clear and has sufficient
instructions to be able to reproduce the issue.
Report a bug by [opening a new issue][new-issue]; it's that easy!


## Feature Request

Great feature requests tend to have:

- A quick idea summary.
- What & why you wanted to add the specific feature.
- Additional context like images, links to resources to implement the feature, etc.



## License

By contributing to BlackboardSync, you agree that your
contributions will be licensed under the LICENSE file in
the root directory of this source tree.

[new-issue]: https://github.com/jacobszpz/BlackboardSync/issues/new

==> blackboardsync-0.12.0rc3.tar.gz: blackboardsync-0.12.0rc3/CONTRIBUTING.md <==
# Contributing to BlackboardSync

We love your input! We want to make contributing to this
project as easy and transparent as possible, whether it is:
- Reporting a issue
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer


## Our Development Process

All changes happen through pull requests,
Pull requests are the best way to propose changes.
We actively welcome your pull requests and invite you to
submit pull requests directly
[here](https://github.com/sanjacob/BlackboardSync/pulls)
and, after review, these can be merged into the project.


## Pull Requests

1. Fork the repository and create your branch from `master`.
2. If you've added code that should be tested, add some tests.
3. Ensure to describe your pull request.


## Local Development

Follow [these instructions](#todo) to set up your own development environment.

You should use the `-d` flag of `pipenv install` to also
install development dependencies.


## Issues

We use GitHub issues to track bugs.
Please ensure your description is clear and has sufficient
instructions to be able to reproduce the issue.
Report a bug by [opening a new issue][new-issue]; it's that easy!


## Feature Request

Great feature requests tend to have:

- A quick idea summary.
- What & why you wanted to add the specific feature.
- Additional context like images, links to resources to implement the feature, etc.



## License

By contributing to BlackboardSync, you agree that your
contributions will be licensed under the LICENSE file in
the root directory of this source tree.

[new-issue]: https://github.com/sanjacob/BlackboardSync/issues/new
